#!/usr/bin/perl

use warnings;
use strict;

use Data::Dumper;
use Getopt::Long;
use Term::ANSIColor qw(:constants);

my %opt;
if (!GetOptions (
        \%opt,

        'translationFile=s'
    )
) {
}

if (!exists $opt{translationFile}) {
    print "Expecting argument --translationFile=<input file>\n";
}
print "Translating file: $opt{translationFile}\n";

# Open input file
open my $fh, '<', $opt{translationFile} or die "Can't open file $!";

# Open output file
open my $outFile, '>', "$opt{translationFile}.new" or die "Can't open file $!";

my $translatedText = "";
while (my $line = <$fh>) {
    if ($line =~ /<source>(.*)<\/source/) {
        # Get the source text
        my $sourceText = $1;
        chomp $sourceText;

        # For some reason the text 'mux:' hangs the translation app, so skip it
        if ($sourceText =~ /mux:/) {
            $translatedText = "mux:";
        } else {
            # Translate the text
            print "Attempting to translate text: $sourceText\n";
            $translatedText = `trans -brief -no-auto -s en -t sv "$sourceText"`;
            chomp $translatedText;
        }

        # Print out the source text line unmodified
        print $outFile $line;
    } elsif ($line =~ /<translation.*>(.*)<\/translation>/) {
        # Insert the translated text
        print "Inserting translation: $translatedText\n";
        if ($1 ne "") {
            $line =~ s/\Q$1\E<\/translation>/$translatedText<\/translation>/;
        } else {
            $line =~ s/<\/translation>/$translatedText<\/translation>/;
        }

        # Print out the translated text line
        print $outFile $line;
    } else {
        print $outFile $line;
    }

    # Sleep to attempt to not get banned by the translation engine
    sleep(0.5);
}

print "Finished translating\n";

close($fh);
close($outFile);
