#!/bin/bash

NETDIR=/etc/network/interfaces.d
WIRED_DEV=""
WIFI_DEV=""

while getopts ":e:w:" opt; do
    case $opt in
        e) # Ethernet
            WIRED_DEV=${OPTARG}
        ;;

        w) # WiFi
            WIFI_DEV=${OPTARG}
        ;;

        \?)
            echo "Invalid option: -$OPTARG" >&2
        ;;
  esac
done
shift $((${OPTIND} - 1))


echo stopping networking
sudo ifdown -a --exclude=lo

find ${NETDIR} -maxdepth 1 -name *.cfg -exec sudo unlink {} 2>/dev/null \;

if [ -n "${WIRED_DEV}" ]; then
    echo enabling ethernet interface
    sudo ln -sf ${NETDIR}/${WIRED_DEV} ${NETDIR}/${WIRED_DEV}.cfg
fi

# /tmp/wpa_supplicant.conf.new is written in QML. Copy to the proper location here.
if [ -n "${WIFI_DEV}" ]; then
    if [ -f "/tmp/wpa_supplicant.conf.new" ]; then
        sudo mv "/tmp/wpa_supplicant.conf.new" "/etc/wpa_supplicant.conf"
    fi

    echo switching interface to wireless
    sudo ln -sf ${NETDIR}/${WIFI_DEV} ${NETDIR}/${WIFI_DEV}.cfg
fi

sync
echo restarting networking...

if [ -n "${WIRED_DEV}" ]; then
    echo restarting "Wired network interface.."
    timeout 60s bash -c "sudo ifup ${WIRED_DEV} --exclude=lo"
fi

if [ -n "${WIFI_DEV}" ]; then
    echo restarting "Wifi network interface.."
    timeout 60s bash -c "sudo ifup ${WIFI_DEV} --exclude=lo"
fi
