#!/bin/bash

# If a file exists that specifies the interfaces, use it instead of detecting
IFACES_OVERRIDE=/data/network-ifaces.override
[ -f ${IFACES_OVERRIDE} ] && {
    cat ${IFACES_OVERRIDE}
    exit 0
}

# Wired interface to use and whether it has an active connection
IFACE_WIRED=""
IFACE_WIRED_ACTIVE=no
# Wireless interface to use and whether it has an active connection
IFACE_WIRELESS=""
IFACE_WIRELESS_ACTIVE=no

# Extract the list of possible connections
LINKS=$(ip link show | perl -n -e 'print if s/^\d+:\s+(.*):\s+<(.*)>.*$/$1:$2/mg')
# Split list of links
while IFS=' ' read -ra link; do
    # Grab the interface name from the link
    IFACE=$(echo ${link} | perl -n -e 'print if s/^(.*):.*/$1/')
    # If the interface has not been assigned yet, assign it
    # If the assigned interface does not have a connection and this
    #  one does, overwrite the assignment
    # If neither / both do, stay with the first one
    case $IFACE in
        enp*) # Wired / ethernet
            if [ -z "${IFACE_WIRED}" ]; then
                IFACE_WIRED=${IFACE}
                # Check if it has an active connection (i.e., has a carrier)
                [ -n "$(echo ${link} | grep -v 'NO-CARRIER')" ] && {
                    IFACE_WIRED_ACTIVE=yes
                }
            elif [ "${IFACE_WIRED_ACTIVE}" == no ] && [ -n "$(echo ${link} | grep -v 'NO-CARRIER')" ]; then
                IFACE_WIRED=${IFACE}
                IFACE_WIRED_ACTIVE=yes
            fi
        ;;

        wlp*) # Wireless
            if [ -z "${IFACE_WIRELESS}" ]; then
                IFACE_WIRELESS=${IFACE}
                # Check if it has an active connection (i.e., has a carrier)
                [ -n "$(echo ${link} | grep -v 'NO-CARRIER')" ] && {
                    IFACE_WIRELESS_ACTIVE=yes
                }
            elif [ "${IFACE_WIRELESS_ACTIVE}" == no ] && [ -n "$(echo ${link} | grep -v 'NO-CARRIER')" ]; then
                IFACE_WIRELESS=${IFACE}
                IFACE_WIRELESS_ACTIVE=yes
            fi
        ;;
    esac
done <<< ${LINKS}

echo "${IFACE_WIRED},${IFACE_WIRELESS}"
exit 0
