#!/bin/bash
set -x

WIRED_DEV=$1
WIFI_DEV=$2
MAX_INCLINE=$3
MAX_SPEED=$4

INPUT_DIR=/media/usb/settings/

DATA_DIR=/data/
SLIDE_DIR=slideshow/user
FACILITY_DIR=facility/user
VID_DIR=video/attract/user
TV_CONF=tv_conf.xml

OPTIONS=/home/true/.config/TrueFitness/TouchApp.conf

WIFI=/etc/wpa_supplicant.conf

# screensaver slides
if [ -d ${INPUT_DIR}${SLIDE_DIR} ]; then
  if [ ! -d ${DATA_DIR}${SLIDE_DIR} ]; then
    mkdir ${DATA_DIR}${SLIDE_DIR}
  fi
  cp ${INPUT_DIR}${SLIDE_DIR}/* ${DATA_DIR}${SLIDE_DIR}/
fi

# facility images
if [ -d ${INPUT_DIR}${FACILITY_DIR} ]; then
  if [ ! -d ${DATA_DIR}${FACILITY_DIR} ]; then
    mkdir ${DATA_DIR}${FACILITY_DIR}
  fi
  cp ${INPUT_DIR}${FACILITY_DIR}/* ${DATA_DIR}${FACILITY_DIR}/
fi

# attract video
if [ -d ${INPUT_DIR}${VID_DIR} ]; then
  if [ ! -d ${DATA_DIR}${VID_DIR} ]; then
    mkdir ${DATA_DIR}${VID_DIR}
  fi
  cp ${INPUT_DIR}${VID_DIR}/* ${DATA_DIR}${VID_DIR}/
fi

# tv channels list 
if [ -f ${INPUT_DIR}${TV_CONF} ]; then
  cp ${INPUT_DIR}${TV_CONF} ${DATA_DIR}${TV_CONF}
fi

# options
cp ${INPUT_DIR}TouchApp.conf $OPTIONS

# Ensure that the speed & incline limits are within range
INCLINE_ENABLED=$(grep maxInclineRegulatorEnabled $OPTIONS | cut -d= -f2)
if [[ $INCLINE_ENABLED = "true" ]]; then
  VALUE=$(grep maxInclineRegulatorValue $OPTIONS | cut -d= -f2)
  if [[ $VALUE -gt $MAX_INCLINE ]]; then
    sed -i -e "s/maxInclineRegulatorValue=$VALUE/maxInclineRegulatorValue=$MAX_INCLINE" $OPTIONS
  fi
fi

SPEED_ENABLED=$(grep maxSpeedRegulatorEnabled $OPTIONS | cut -d= -f2)
if [[ $SPEED_ENABLED = "true" ]]; then
  VALUE=$(grep maxSpeedRegulatorValue $OPTIONS | cut -d= -f2)
  if [[ $VALUE -gt $MAX_SPEED ]]; then
    sed -i -e "s/maxInclineRegulatorValue=$VALUE/maxInclineRegulatorValue=$MAX_SPEED" $OPTIONS
  fi
fi

# network settings

NETDIR=/etc/network/interfaces.d
#WIRED_DEV="enp2s0"
WIRED_CONNECTED=false
SCRIPT_PATH=/usr/lib/truefitness/truetouch/scripts
#WIFI_DEV=($SCRIPT_PATH/get-network-ifaces.sh | cut -d, -f2)

if [ -f ${INPUT_DIR}$WIRED_DEV ]; then
  echo stopping networking
  sudo ifdown -a --exclude=lo

  echo enabling ethernet interface
  sudo ln -sf $NETDIR/$WIRED_DEV $NETDIR/$WIRED_DEV.cfg
  sync
  timeout 60s bash -c "sudo ifup $WIRED_DEV --exclude=lo"

  WIRED_CONNECTED=true
fi

if [ -f ${INPUT_DIR}$WIFI ]; then
  if [ $WIRED_CONNECTED == "false" ]; then
    echo stopping networking
    sudo ifdown -a --exclude=lo

    sudo unlink $NETDIR/$WIRED_DEV.cfg 2>/dev/null
  fi

  echo enabling wifi interface
  sudo bash -c "cp ${INPUT_DIR}$WIFI $WIFI"
  sudo ln -sf $NETDIR/$WIFI_DEV $NETDIR/$WIFI_DEV.cfg
  sync
  timeout 60s bash -c "sudo ifup $WIFI_DEV --exclude=lo"

elif [ $WIRED_CONNECTED == "true" ]; then
  sudo unlink $NETDIR/$WIFI_DEV.cfg 2>/dev/null
fi

# IPTV setup
IPTV_ENABLED=$(grep iptvEnabled $OPTIONS | cut -d= -f2) 
if [ $IPTV_ENABLED == "true" ]; then
  if [ -f ${INPUT_DIR}iptv ]; then
    IP = $(cat ${INPUT_DIR}iptv)
    timeout 60s bash -c $SCRIPT_PATH/iptvRoute/cpRouteFiles.sh $IP
  fi
fi

exit 0
