#!/bin/bash
##
##  truefitness-addroute-atboot.sh
##  Create route for 238/8 on wired Ethernet device
##
##  Override values by editing /etc/default/truefitness-addroute
##
## Version History
## 1.0    First Edition, created to bandaid a problem at a customer site.

#set -o nounset
#set -o errexit

export LANG=C
export LC_ALL=C
readonly myName=$( basename $0 )
readonly myVersion=1.0
readonly myOverride="/etc/default/truefitness-addroute"

function myUsage () {
  printf 'Usage: %s [-h|-u|-v]\n' "$myName"
}

function myHelp () {
  printf 'Creates a new network route, 238/8, for multicast.\n'
  printf 'Normally run by a systemD timer.\n'
  printf '%s is not intended to be run by hand.\n\n' "$myName"
  printf 'Override defaults by modifying %s.\n' "$myOverride"
  myUsage
}

function myVer () {
  printf '%s version: %s\n' "$myName" "$myVersion"
}

function myNetIf () {
  myDelay=${1:=5} 
  myInterface=''
  while [[ -z $myInterface ]] ; do
    myInterface=$( /sbin/ip a | /bin/grep ^[123] | /bin/grep 'state UP ' | /bin/grep enp | /usr/bin/cut -f2 -d: | /bin/sed 's/ //g' )
    if [[ -z $myInterface ]] ; then
      myLogger "No interface found.  I will retry after $myDelay seconds."
      /bin/sleep $myDelay
    fi
  done
  /bin/echo $myInterface
}

function myLogger () {
  if [[ -e /usr/bin/systemd-cat ]] ; then
    /bin/echo "$1" | /usr/bin/systemd-cat -t "${myName}" -p info
  fi
}

while getopts ':huv' opt; do
  case ${opt} in
    h) myHelp
       exit 0
       ;;
    u) myUsage
       exit 0
       ;;
    v) myVer
       exit 0
       ;;
    *) printf '\n%s: ERROR: Invalid Option\n' $myName
       myUsage
       exit 1
       ;;
  esac
done


# Default values.
# Does this always come up with 1 address???
#NetInterface=$( /sbin/ip a | /bin/grep ^[123] | /bin/grep 'state UP ' | /bin/grep enp | /usr/bin/cut -f2 -d: | /bin/sed 's/ //g' )
MultiNet='238/8'
StartDelay=0
RetryDelay=5

# Find the wired interface.  $myOverride can change it. 
# If no interface is found, wait $RetryDelay seconds and try again.
NetInterface="$( myNetIf $RetryDelay )"
NetIfTemp="$NetInterface"

if [[ -r $myOverride ]] ; then
  . $myOverride
  if [[ $RetryDelay < 5 ]] ; then RetryDelay=5 ; fi
fi

# Do we have a valid Interface?  Perhaps the override has a typo?
if /sbin/ip address | /bin/grep ' state UP ' | /bin/grep "$NetInterface" >/dev/null 2>&1 ; then
  # It's good, do nothing.
  # This is a valid noop 
  :
else
  if /sbin/ip address | /bin/grep ' state UP ' | /bin/grep "$NetIfTemp" >/dev/null 2>&1 ; then
    NetInterface="$NetIfTemp"
  else
    NetInterface="$( myNetIf $RetryDelay )"
  fi
fi

# Shouldn't need this with the ExecStartPre in the service.
if [[ $StartDelay > 0 ]] ; then
  /bin/sleep $StartDelay
fi


# UP wired Ethernet interface
# ip a | grep ^[123] | grep 'state UP ' | grep enp | cut -f2 -d:
# The command
# /sbin/ip route add 238/8 dev enp2s0
/sbin/ip route add "$MultiNet" dev "$NetInterface"

myLogger "Interface  $NetInterface"
myLogger "Netmask    $MultiNet"
myLogger "StartDelay $StartDelay"
myLogger "RetryDelay $RetryDelay"

myLogger "Added route .${MultiNet}. device .${NetInterface}."
