#!/bin/bash
set -x

SCRIPTDIR=$(cd "$( dirname "$0" )" && pwd )
SERIAL_SCRIPT="$SCRIPTDIR/../product_serial.sh"
# Slack configuration
SLACKTEE_CONF=$SCRIPTDIR/slack/slacktee.conf
function slack() {
  SLACKTEE_CONF=$SLACKTEE_CONF $SCRIPTDIR/slack/slacktee.sh
}

#Install key on console
#
THISDIR=$(pwd)
echo $THISDIR

if [ ! -d ~/.ssh ]; then
	mkdir ~/.ssh
fi
sudo chmod 700 ~/.ssh
cd ~/.ssh 
touch authorized_keys
sudo chmod 600 authorized_keys
cd "$THISDIR"
echo $PWD
KEYFILE="$SCRIPTDIR/".ssh/id_remote_true_dsa.pub
if ! grep "$(cat $KEYFILE)" ~/.ssh/authorized_keys; then
    echo Adding key to authorized_keys file
    sudo cat $KEYFILE >> ~/.ssh/authorized_keys
fi


# Establish ssh connection
#
if [ -e "$SERIAL_SCRIPT" ]; then
	SERIAL=$(sh "$SERIAL_SCRIPT" ARM )
	# 9000 + last three digits of serial 9DDD
	echo serial is $SERIAL
	ID=$(echo $SERIAL | awk  '{ string=substr($0, 9, 3); print string; }' )
	echo $ID
	rnumber=$RANDOM
        let "rnumber %= 999"
	CLIENT_PORT="9${rnumber}"
	echo "CLIENT_PORT ${CLIENT_PORT}"
else
	CLIENT_PORT="9001"
fi
echo port is $CLIENT_PORT

# Only print on first attempt
if [[ $RETRY_ATTEMPTS -eq 0 ]]; then
  echo "New connection attempt from $SERIAL $CLIENT_PORT" | slack
fi

GPGKEY="$SCRIPTDIR"/"gpg/remote_console.pem"
sudo chmod 0600 $GPGKEY
HOSTNAME="localhost"
HOST_PORT="22"
USERNAME="trueconsole"
SERVER="diagnostics.truefitness.com"
SSH_OPTIONS="-oStrictHostKeyChecking=no "
# These options ensure that the connection is dropped in case of network interruption
SSH_OPTIONS+="-oServerAliveInterval=15 -oServerAliveCountMax=1 "
SSH_OPTIONS+="-oExitOnForwardFailure=yes "

COMMAND="ssh -N -i  ${GPGKEY} ${SSH_OPTIONS} -R ${CLIENT_PORT}:${HOSTNAME}:${HOST_PORT} ${USERNAME}@${SERVER} -v"

#ssh -N -i ./gpg/remote_console.pem -oStrictHostKeyChecking=no -R 9004:localhost:22 trueconsole@ec2-54-186-116-202.us-west-2.compute.amazonaws.com
echo ${COMMAND}
${COMMAND}
