#!/bin/bash

# Dynamically determining the primary output is slow
#  If the output should be dynamic, then it should be checked on boot, saved, and referenced
#PRIMARY_OUTPUT=$(xrandr --listactivemonitors | awk '{if($4){print $4; exit;}}')
PRIMARY_OUTPUT=eDP-1

# Only non-negative floating point values accepted
[[ "$1" =~ ^[0-9]+\.?[0-9]*$ ]] || exit 1

OSVERS="$(lsb_release -rs)"
case "${OSVERS}" in
    "20.04")
        # Set the brightness
        #  Value for brightness should be between 0 and 1
        #  It can go higher, but it probably harms the health of the screen
        #  Setting the brightness to 0 may put the screen in a state where it is non-
        #   interactable.  Set brightness to 0.1% instead.
        if [ $(bc -l <<< "$1 <= 0") -ne 0 ]; then
            BRIGHTNESS=0.001
        elif [ $(bc -l <<< "$1 > 1") -ne 0 ]; then
            BRIGHTNESS=1.0
        else
            BRIGHTNESS=$1
        fi

        xrandr --output ${PRIMARY_OUTPUT} --brightness ${BRIGHTNESS}
    ;;

    "17.04")
        MAX_BRIGHTNESS=6000
        BRIGHTNESS=$(bc -l <<< "$1*${MAX_BRIGHTNESS}")
        printf "%.0f" "${BRIGHTNESS}" | sudo tee /sys/class/backlight/intel_backlight/brightness
    ;;
esac
